pub enum PurwaError {
Validation(ValidationErrors),
MalformedJson(String),
MalformedForm(String),
Unauthorized {
message: String,
},
Forbidden {
message: String,
},
NotFound {
message: String,
},
Database(Error),
Internal {
message: String,
},
}Expand description
Central framework error type.
Variants
Validation(ValidationErrors)
Field validation failed (validator::Validate); 422.
MalformedJson(String)
JSON body could not be parsed or did not match the DTO; 400.
MalformedForm(String)
Form or query deserialization failed; 400.
Session or credentials missing; 401.
Fields
Forbidden
Authenticated but not allowed; 403.
NotFound
Resource not found; 404.
Database(Error)
Database layer failure; 500 (details logged, not echoed).
Internal
Generic server error; 500 (message is safe for clients).
Implementations
Sourceimpl PurwaError
impl PurwaError
pub fn forbidden(message: impl Into<String>) -> Self
pub fn not_found(message: impl Into<String>) -> Self
pub fn internal(message: impl Into<String>) -> Self
Sourcepub fn from_json_rejection(rejection: JsonRejection) -> Self
pub fn from_json_rejection(rejection: JsonRejection) -> Self
Convert Axum’s JsonRejection into 400 PurwaError::MalformedJson.
Sourcepub fn from_form_rejection(rejection: FormRejection) -> Self
pub fn from_form_rejection(rejection: FormRejection) -> Self
Convert Axum’s FormRejection into 400 PurwaError::MalformedForm.
Sourcepub fn status_code(&self) -> StatusCode
pub fn status_code(&self) -> StatusCode
HTTP status for this error.
Sourcepub fn inertia_error_props(&self) -> Value
pub fn inertia_error_props(&self) -> Value
JSON value merged into Inertia page props for the shared Error page component.
Sourcepub fn validation_errors_map_json(&self) -> Map<String, Value>
pub fn validation_errors_map_json(&self) -> Map<String, Value>
Flat errors object for Inertia (empty unless validation).